package com.soap.ws.configuration;

import org.springframework.boot.web.servlet.ServletRegistrationBean;
import org.springframework.context.ApplicationContext;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.io.ClassPathResource;
import org.springframework.ws.config.annotation.EnableWs;
import org.springframework.ws.config.annotation.WsConfigurerAdapter;
import org.springframework.ws.transport.http.MessageDispatcherServlet;
import org.springframework.ws.wsdl.wsdl11.DefaultWsdl11Definition;
import org.springframework.xml.xsd.SimpleXsdSchema;
import org.springframework.xml.xsd.XsdSchema;

/**
 * Created by with IntelliJ IDEA.
 * User: pradeep
 * Date: 17/2/17
 * Time: 5:13 PM
 */

@EnableWs
@Configuration
public class WebServiceConfig extends WsConfigurerAdapter {

    /*
    * For handling SOAP messages Spring WS uses MessageDispatcherServlet
    * Inject applicationContext into MessageDispatcherServlet to detect spring beans automatically.
    * will not replace default dispatcher servlet
    * */
    @Bean
    public ServletRegistrationBean messageDispatcherServlet(ApplicationContext applicationContext) {
        MessageDispatcherServlet servlet = new MessageDispatcherServlet();
        servlet.setApplicationContext(applicationContext);
        servlet.setTransformWsdlLocations(true);
        return new ServletRegistrationBean(servlet, "/ws/*");
    }


    /*
    * Expose standard ws to client
    * */
    @Bean(name = "countries")
    public DefaultWsdl11Definition defaultCountryWsdl11Definition(XsdSchema countriesSchema) {
        DefaultWsdl11Definition wsdl11Definition = new DefaultWsdl11Definition();
        wsdl11Definition.setPortTypeName("CountriesPort");
        wsdl11Definition.setLocationUri("/ws");
        wsdl11Definition.setTargetNamespace("http://soap.com/ws/xjc");
        wsdl11Definition.setSchema(countriesSchema);
        return wsdl11Definition;
    }

    @Bean
    public XsdSchema countriesSchema() {
        return new SimpleXsdSchema(new ClassPathResource("xsd/countries.xsd"));
    }

    @Bean(name = "members")
    public DefaultWsdl11Definition defaultMemberWsdl11Definition(XsdSchema membersSchema) {
        DefaultWsdl11Definition wsdl11Definition = new DefaultWsdl11Definition();
        wsdl11Definition.setPortTypeName("MembersPort");
        wsdl11Definition.setLocationUri("/ws");
        wsdl11Definition.setTargetNamespace("http://soap.com/ws/xjc");
        wsdl11Definition.setSchema(membersSchema);
        return wsdl11Definition;
    }

    @Bean
    public XsdSchema membersSchema() {
        return new SimpleXsdSchema(new ClassPathResource("xsd/members.xsd"));
    }
}
